Skip to contents

Infer cell-cell communication in spatial transcriptomics data using collective optimal transport (COT). COMMOTR provides a complete workflow for analyzing ligand-receptor interactions with spatial constraints.

Details

COMMOTR implements the COMMOT algorithm from Cang et al. (Nature Methods, 2023) in R with high-performance C++ backends for optimal transport computations.

Core Analysis Functions:

Data Functions:

Visualization Functions:

References

Cang, Z., Zhao, Y., Almet, A.A. et al. Screening cell-cell communication in spatial transcriptomics via collective optimal transport. Nature Methods 20, 218-228 (2023). doi:10.1038/s41592-022-01728-4

Author

Zaoqu Liu liuzaoqu@163.com