COMMOTR: Cell-Cell Communication via Collective Optimal Transport
Source:R/COMMOTR-package.R
COMMOTR-package.RdInfer cell-cell communication in spatial transcriptomics data using collective optimal transport (COT). COMMOTR provides a complete workflow for analyzing ligand-receptor interactions with spatial constraints.
Details
COMMOTR implements the COMMOT algorithm from Cang et al. (Nature Methods, 2023) in R with high-performance C++ backends for optimal transport computations.
Core Analysis Functions:
spatial_communication: Infer cell-cell communicationcommunication_direction: Compute communication directionscluster_communication: Cluster-level analysis
Data Functions:
ligand_receptor_database: Load LR databasesfilter_lr_database: Filter LR pairs by expression
Visualization Functions:
plot_cell_communication: Cell-level plots with vector fieldsplot_cluster_communication: Cluster-level network plotsplot_communication_dotplot: Dotplot visualization
References
Cang, Z., Zhao, Y., Almet, A.A. et al. Screening cell-cell communication in spatial transcriptomics via collective optimal transport. Nature Methods 20, 218-228 (2023). doi:10.1038/s41592-022-01728-4
See also
Original COMMOT: https://github.com/zcang/COMMOT
Author
Zaoqu Liu liuzaoqu@163.com